@@ -1,10 +1,11 @@
-# -*- coding: utf-8 -*-
-
-# Copyright (c) 2013 by tzf.pyramid_routing authors and contributors <see AUTHORS file>
+# Copyright (c) 2013 by tzf.pyramid_routing authors and contributors
+# <see AUTHORS file>
 #
 # This module is part of tzf.pyramid_routing and is released under
 # the MIT License (MIT): http://opensource.org/licenses/MIT
 
+"""Main namespace module."""
+
 # See http://peak.telecommunity.com/DevCenter/setuptools#namespace-packages
 try:
     __import__('pkg_resources').declare_namespace(__name__)
